@@ -1,9 +1,9 @@
 import console.utils
 from colorama import Fore
-from console import *
-from arcade import *
+from console import utils
+import os
 
-class color():
+class mcolor():
     def inf(information):
         green = Fore.GREEN
         reset = Fore.RESET
@@ -31,29 +31,16 @@ class color():
     def title(titlestr):
         magenta = Fore.MAGENTA
         reset = Fore.RESET
-        print('[' + magenta + reset + ']' + titlestr)
+        print(magenta + titlestr)
 
     pass
 
 class cons():
     def title(name):
         console.utils.set_title(name)
+        color.inf('已设置标题为 {}'.format(name))
         pass
     pass
 
-class arcade_mixed():
-    def render():
-        start_render()
-        pass
-
-    def set_bc(color):
-        set_background_color(color)
-        pass
-
-    def d_circle_o(x,y,radius,color,b_width=1,ta=0,ns=-1):
-        draw_circle_outline(x,y,radius,color,b_width,ta,ns)
-    pass
-
 if __name__ == '__main__':
-    color.inf('test')
     pass
